==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_pca_connector_scep/paginator.py <==
"""
Type annotations for pca-connector-scep service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_pca_connector_scep.client import PrivateCAConnectorforSCEPClient
    from types_boto3_pca_connector_scep.paginator import (
        ListChallengeMetadataPaginator,
        ListConnectorsPaginator,
    )

    session = Session()
    client: PrivateCAConnectorforSCEPClient = session.client("pca-connector-scep")

    list_challenge_metadata_paginator: ListChallengeMetadataPaginator = client.get_paginator("list_challenge_metadata")
    list_connectors_paginator: ListConnectorsPaginator = client.get_paginator("list_connectors")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListChallengeMetadataRequestListChallengeMetadataPaginateTypeDef,
    ListChallengeMetadataResponseTypeDef,
    ListConnectorsRequestListConnectorsPaginateTypeDef,
    ListConnectorsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListChallengeMetadataPaginator", "ListConnectorsPaginator")


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListChallengeMetadataPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep/paginator/ListChallengeMetadata.html#PrivateCAConnectorforSCEP.Paginator.ListChallengeMetadata)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/#listchallengemetadatapaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListChallengeMetadataRequestListChallengeMetadataPaginateTypeDef]
    ) -> _PageIterator[ListChallengeMetadataResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep/paginator/ListChallengeMetadata.html#PrivateCAConnectorforSCEP.Paginator.ListChallengeMetadata.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/#listchallengemetadatapaginator)
        """


class ListConnectorsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep/paginator/ListConnectors.html#PrivateCAConnectorforSCEP.Paginator.ListConnectors)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/#listconnectorspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListConnectorsRequestListConnectorsPaginateTypeDef]
    ) -> _PageIterator[ListConnectorsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep/paginator/ListConnectors.html#PrivateCAConnectorforSCEP.Paginator.ListConnectors.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/#listconnectorspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_pca_connector_scep/paginator.py <==
"""
Type annotations for pca-connector-scep service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_pca_connector_scep.client import PrivateCAConnectorforSCEPClient
    from types_boto3_pca_connector_scep.paginator import (
        ListChallengeMetadataPaginator,
        ListConnectorsPaginator,
    )

    session = Session()
    client: PrivateCAConnectorforSCEPClient = session.client("pca-connector-scep")

    list_challenge_metadata_paginator: ListChallengeMetadataPaginator = client.get_paginator("list_challenge_metadata")
    list_connectors_paginator: ListConnectorsPaginator = client.get_paginator("list_connectors")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListChallengeMetadataRequestPaginateTypeDef,
    ListChallengeMetadataResponseTypeDef,
    ListConnectorsRequestPaginateTypeDef,
    ListConnectorsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListChallengeMetadataPaginator", "ListConnectorsPaginator")


if TYPE_CHECKING:
    _ListChallengeMetadataPaginatorBase = Paginator[ListChallengeMetadataResponseTypeDef]
else:
    _ListChallengeMetadataPaginatorBase = Paginator  # type: ignore[assignment]


class ListChallengeMetadataPaginator(_ListChallengeMetadataPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep/paginator/ListChallengeMetadata.html#PrivateCAConnectorforSCEP.Paginator.ListChallengeMetadata)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/#listchallengemetadatapaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListChallengeMetadataRequestPaginateTypeDef]
    ) -> PageIterator[ListChallengeMetadataResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep/paginator/ListChallengeMetadata.html#PrivateCAConnectorforSCEP.Paginator.ListChallengeMetadata.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/#listchallengemetadatapaginator)
        """


if TYPE_CHECKING:
    _ListConnectorsPaginatorBase = Paginator[ListConnectorsResponseTypeDef]
else:
    _ListConnectorsPaginatorBase = Paginator  # type: ignore[assignment]


class ListConnectorsPaginator(_ListConnectorsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep/paginator/ListConnectors.html#PrivateCAConnectorforSCEP.Paginator.ListConnectors)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/#listconnectorspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListConnectorsRequestPaginateTypeDef]
    ) -> PageIterator[ListConnectorsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep/paginator/ListConnectors.html#PrivateCAConnectorforSCEP.Paginator.ListConnectors.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_pca_connector_scep/paginators/#listconnectorspaginator)
        """
